@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 # Modify the config.json.sample file, save it to config.json. Run server.pl on
 # server, run client.pl on localhost. Config your browser to use socks 5 proxy
 # with remote DNS support and you can now break through the great firewall of
@@ -7,22 +7,8 @@
 use 5.006;
 use strict;
 use warnings;
-use Getopt::Long;
 use JSON;
 use Net::Shadowsocks::Client;
-use Term::ANSIColor;
-
-sub print_help {
-   print("Usage: vmcomlite.pl [-a] [-h] [-g]\n\n");
-   print("-a FILE, --analyse=FILE\t\tAnalyse FILE\n");
-   print("-ho PW, --hostpass=PW\t\tUse PW as password to the host OS\n");
-   print("-g PW, --guestpass=PW\t\tUse PW as password to the virtual machine's OS\n");
-   print("-t, --takesnapshot\t\tTake a snapshot of the virtual machine's state\n");
-   print("\t\t\t\t(maximum one snapshot can be stored per virtual\n");
-   print("\t\t\t\tmachine for VMware Server)\n");
-   print("-he, --help\t\t\tThis help screen\n");
-   die "\n"; 
-}
 
 local $/;
 open(my $fh, '<', 'config.json') or die "Can't open  config.json: $!";
