@@ -23,6 +23,7 @@ use Crypt::AuthEnc::GCM;
 use Crypt::Cipher::AES;
 use Crypt::Cipher::Camellia;
 use Crypt::Cipher::RC6;
+use Crypt::HC128;
 use Crypt::KeyDerivation qw(hkdf);
 use Crypt::Mode::CFB;
 use Crypt::Mode::CTR;
@@ -40,7 +41,7 @@ use Digest::MD5;
 #use Mcrypt qw(:FUNCS);
 #use String::HexConvert ':all';
 
-our $VERSION = '0.9.2';
+our $VERSION = '0.9.3';
 
 our %_ciphers = 
     (
@@ -301,41 +302,41 @@ sub _get_iv_size($)
     }
 }
 
-sub _add_padding($$$)
+sub _add_padding($$)
 {
         # add required padding so we can recover the original string length after decryption
         # (padding bytes have value set to padding length)
-        my $_method = shift;
+        #my $_method = shift;
         my $_pt = shift;
         my $_pad_len = shift;
-        my $_block_size = _get_key_size($_method);
+        #my $_block_size = _get_key_size($_method);
         #my $_pt_len = length($_pt)  % $_block_size;
         #my $_pad_len = $_block_size - $_pt_len;
-        $_pt .= (chr($_pad_len)) x $_pad_len unless $_pad_len == $_block_size;
-        #$_pt = (chr(0)) x $_pad_len . $_pt unless $_pad_len == $_block_size;
+        #$_pt .= (chr($_pad_len)) x $_pad_len unless $_pad_len == $_block_size;
+        $_pt = (chr(0)) x $_pad_len . $_pt ;
         return $_pt;
 }
 
 
 
-sub _remove_padding($$$)
+sub _remove_padding($$)
 {
         # remove padding if necessary (padding byte value gives length of padding)
-        my $_method = shift;
+        #my $_method = shift;
         my $_ct = shift;
         my $_pad_len = shift;
-        my $_ct_len = length($_ct);
-        my $_block_size = _get_key_size($_method);
+        #my $_ct_len = length($_ct);
+        #my $_block_size = _get_key_size($_method);
         #my $_pad_len = ord(substr($_ct, -1, 1));
-        if ($_pad_len > $_block_size)
-        {
-            AE::log error => "invalid pad byte";
-        }
-        else
-        {
-        $_ct  = substr($_ct, 0, $_ct_len - $_pad_len);
-        #$_ct  = substr($_ct, $_pad_len, $_ct_len - $_pad_len);
-        }
+        #if ($_pad_len > $_block_size)
+        #{
+        #    AE::log error => "invalid pad byte";
+        #}
+        #else
+        #{
+        #$_ct  = substr($_ct, 0, $_ct_len - $_pad_len);
+        $_ct  = substr($_ct, $_pad_len);
+        #}
         return $_ct;
 }
 1;    # End of Net::Shadowsocks
@@ -352,7 +353,7 @@ Net::Shadowsocks - the asynchronous, non-blocking shadowsocks client and server.
 
 =head1 VERSION
 
-Version 0.9.2
+Version 0.9.3
 
 =head1 SYNOPSIS
     
