@@ -32,7 +32,7 @@ package Net::Shadowsocks::Client;
     use Socket qw(IPPROTO_TCP MSG_FASTOPEN SOL_SOCKET SO_REUSEPORT SO_REUSEADDR);
     #use String::HexConvert ':all';
     
-    our $VERSION = '0.9.2';
+    our $VERSION = '0.9.3';
     $AnyEvent::Log::FILTER->level ("info");
     sub new($$$$$$) 
     {
@@ -275,13 +275,13 @@ package Net::Shadowsocks::Client;
                                                         if ($self->{method} eq 'chacha20-ietf')
                                                         {
                                                             #my $ct_len = length($incoming_data)  % 64;
-                                                            #my $pad_len = 64 - $ct_len;
-                                                            #my $padded_incoming_data  = Net::Shadowsocks::_add_padding($incoming_data,$pad_len); 
-                                                            #my $padded_decrypted_data = $decryptor->chacha20_ietf_xor_ic($padded_incoming_data,$server_iv,$decrypt_counter ,$key);
-                                                            $decrypted_data = $decryptor->chacha20_ietf_xor_ic($incoming_data,$server_iv,$decrypt_counter ,$key);
-                                                            #$decrypted_data = Net::Shadowsocks::_remove_padding($padded_decrypted_data,$pad_len);
+                                                            my $pad_len = $decrypt_counter % 64 ;
+                                                            my $padded_incoming_data  = Net::Shadowsocks::_add_padding($incoming_data,$pad_len); 
+                                                            my $padded_decrypted_data = $decryptor->chacha20_ietf_xor_ic($padded_incoming_data,$server_iv,$decrypt_counter / 64 ,$key);
+                                                            #$decrypted_data = $decryptor->chacha20_ietf_xor_ic($incoming_data,$server_iv,$decrypt_counter / 64 ,$key);
+                                                            $decrypted_data = Net::Shadowsocks::_remove_padding($padded_decrypted_data,$pad_len);
                                                             #$decrypted_data = $decryptor->chacha20_ietf_xor($incoming_data,$server_iv ,$key);
-                                                            $decrypt_counter +=  length($incoming_data) / 64;
+                                                            $decrypt_counter +=  length($incoming_data);
                                                         }
                                                         else
                                                         {
@@ -458,13 +458,13 @@ package Net::Shadowsocks::Client;
                                     if($self->{method} eq 'chacha20-ietf')
                                     {
                                         #my $pt_len = length($plain_data)  % 64;
-                                        #my $pad_len = 64 - $pt_len;
-                                        #my $padded_plain_data  = Net::Shadowsocks::_add_padding($plain_data,$pad_len); 
-                                        #my $padded_encrypted_data = $encryptor->chacha20_ietf_xor_ic($padded_plain_data,$encrypt_nonce,$encrypt_counter,$key);
-                                        $encrypted_data = $encryptor->chacha20_ietf_xor_ic($plain_data,$encrypt_nonce,$encrypt_counter,$key);
-                                        #$encrypted_data = Net::Shadowsocks::_remove_padding($padded_encrypted_data,$pad_len);
+                                        my $pad_len = $encrypt_counter % 64;
+                                        my $padded_plain_data  = Net::Shadowsocks::_add_padding($plain_data,$pad_len); 
+                                        my $padded_encrypted_data = $encryptor->chacha20_ietf_xor_ic($padded_plain_data,$encrypt_nonce,$encrypt_counter /64 ,$key);
+                                        #$encrypted_data = $encryptor->chacha20_ietf_xor_ic($plain_data,$encrypt_nonce,$encrypt_counter / 64,$key);
+                                        $encrypted_data = Net::Shadowsocks::_remove_padding($padded_encrypted_data,$pad_len);
                                         #$decrypted_data = $encryptor->chacha20_ietf_xor($plain_data,$iv,$key);
-                                        $encrypt_counter += length($plain_data) /64;
+                                        $encrypt_counter += length($plain_data) ;
                                     }
                                     else
                                     {
@@ -559,7 +559,7 @@ Net::Shadowsocks::Client - Shadowsocks protocol client module.
 
 =head1 VERSION
 
-Version 0.9.2
+Version 0.9.3
 
 =head1 SYNOPSIS
 
