@@ -31,7 +31,7 @@
     use Socket qw(IPPROTO_TCP TCP_FASTOPEN SOL_SOCKET SO_REUSEPORT SO_REUSEADDR);
     #use String::HexConvert ':all';
     
-    our $VERSION = '0.9.2';
+    our $VERSION = '0.9.3';
     
     $AnyEvent::Log::FILTER->level ("info");
     
@@ -166,15 +166,14 @@
                                      {
                                         if ($self->{method} eq 'chacha20-ietf')
                                         {
-                                           #$decrypted_data = $decryptor->process($incoming_data);
                                            #my $ct_len = length($incoming_data)  % 64;
-                                           #my $pad_len = 64 - $ct_len;
-                                           #my $padded_incoming_data  = Net::Shadowsocks::_add_padding($incoming_data,$pad_len); 
-                                           #my $padded_decrypted_data = $decryptor->chacha20_ietf_xor_ic($padded_incoming_data,$client_iv,$decrypt_counter,$key);
-                                           $decrypted_data = $decryptor->chacha20_ietf_xor_ic($incoming_data,$client_iv,$decrypt_counter,$key);
-                                           #$decrypted_data = Net::Shadowsocks::_remove_padding($padded_decrypted_data,$pad_len);
+                                           my $pad_len = $decrypt_counter % 64;
+                                           my $padded_incoming_data  = Net::Shadowsocks::_add_padding($incoming_data,$pad_len); 
+                                           my $padded_decrypted_data = $decryptor->chacha20_ietf_xor_ic($padded_incoming_data,$client_iv,$decrypt_counter / 64,$key);
+                                           #$decrypted_data = $decryptor->chacha20_ietf_xor_ic($incoming_data,$client_iv,$decrypt_counter,$key);
+                                           $decrypted_data = Net::Shadowsocks::_remove_padding($padded_decrypted_data,$pad_len);
                                            #$decrypted_data = $decryptor->chacha20_ietf_xor($incoming_data,$client_iv,$key);
-                                           $decrypt_counter += length($incoming_data) / 64;
+                                           $decrypt_counter += length($incoming_data);
                                        }
                                        else
                                        {
@@ -425,16 +424,14 @@
                                                       elsif($self->{method} =~ /^chacha20/)
                                                       {
                                                           if($self->{method} eq "chacha20-ietf")
-                                                          {
-                                                              #$encrypted_data = $encryptor->process($plain_data);
+                                                          {        
                                                               #my $pt_len = length($plain_data)  % 64;
-                                                              #my $pad_len = 64 - $pt_len;
-                                                              #my $padded_plain_data  = Net::Shadowsocks::_add_padding($plain_data,$pad_len);    
-                                                              #my $padded_encrypted_data = $encryptor->chacha20_ietf_xor_ic($padded_plain_data,$iv,$encrypt_counter,$key);
-                                                              $encrypted_data = $encryptor->chacha20_ietf_xor_ic($plain_data,$iv,$encrypt_counter,$key);
-                                                              #$encrypted_data = $encryptor->chacha20_ietf_xor($plain_data,$iv,$key);
-                                                              #$encrypted_data = Net::Shadowsocks::_remove_padding($padded_encrypted_data,$pad_len);
-                                                              $encrypt_counter += length($plain_data) / 64;
+                                                              my $pad_len = $encrypt_counter % 64 ;
+                                                              my $padded_plain_data  = Net::Shadowsocks::_add_padding($plain_data,$pad_len);    
+                                                              my $padded_encrypted_data = $encryptor->chacha20_ietf_xor_ic($padded_plain_data,$iv,$encrypt_counter / 64,$key);
+                                                              #$encrypted_data = $encryptor->chacha20_ietf_xor_ic($plain_data,$iv,$encrypt_counter,$key);
+                                                              $encrypted_data = Net::Shadowsocks::_remove_padding($padded_encrypted_data,$pad_len);
+                                                              $encrypt_counter += length($plain_data) ;
                                                           }
                                                           else
                                                           {
@@ -509,15 +506,14 @@
                                      {
                                         if ($self->{method} eq "chacha20-ietf")
                                         {
-                                           #$decrypted_data = $decryptor->process($incoming_data);
+                                          
                                            #my $ct_len = length($incoming_data)  % 64;
-                                           #my $pad_len = 64 - $ct_len;
-                                           #my $padded_incoming_data  = Net::Shadowsocks::_add_padding($incoming_data,$pad_len); 
-                                           #my $padded_decrypted_data = $decryptor->chacha20_ietf_xor_ic($padded_incoming_data,$client_iv,$decrypt_counter,$key);
-                                           $decrypted_data = $decryptor->chacha20_ietf_xor_ic($incoming_data,$client_iv,$decrypt_counter,$key);
-                                           #$decrypted_data = Net::Shadowsocks::_remove_padding($padded_decrypted_data,$pad_len);
-                                           #$decrypted_data = $decryptor->chacha20_ietf_xor($incoming_data,$client_iv,$key);
-                                           $decrypt_counter += length($incoming_data) / 64;
+                                           my $pad_len = $decrypt_counter % 64 ;
+                                           my $padded_incoming_data  = Net::Shadowsocks::_add_padding($incoming_data,$pad_len); 
+                                           my $padded_decrypted_data = $decryptor->chacha20_ietf_xor_ic($padded_incoming_data,$client_iv,$decrypt_counter / 64,$key);
+                                           #$decrypted_data = $decryptor->chacha20_ietf_xor_ic($incoming_data,$client_iv,$decrypt_counter,$key);
+                                           $decrypted_data = Net::Shadowsocks::_remove_padding($padded_decrypted_data,$pad_len);
+                                           $decrypt_counter += length($incoming_data) ;
                                        }
                                        else
                                        {
@@ -701,7 +697,7 @@ Net::Shadowsocks::Server - Shadowsocks protocol server module.
 
 =head1 VERSION
 
-Version 0.9.2
+Version 0.9.3
 
 =head1 SYNOPSIS
 
